var _ = require('lodash');
var databaseHelper = require("./databaseHelper")

/**
 * 辅助生成save方法
 * @param {string}} table 表名
 * @param {string} key 主键名
 */
var saveBuilder = (table, key) => {
    return (req, res) => {
        var body = req.body;
        databaseHelper.saveJsonToDb(body, table, key)
            .then((data) => {
                res.end(JSON.stringify(data));
            }).catch((err) => {
                res.end(err);
            })
    };
}

/**
 * 全量查询生成器
 * @param {string} table 表名
 * @param {Object|Array|string} items  查询项目
 * @param {Array} condition 查询条件
 * @param {*} translate 数据转换
 */
var listAllBuilder = (table, items, condition, translate = (x) => { return x }) => {
    return (req, res) => {

        var cloned = Object.assign({}, condition);;
        if (!_.isEmpty(req.query)) {
            cloned = _.merge(cloned, req.query);
        }

        databaseHelper.listDbByJson(cloned, table, items)
            .then((data) => {
                res.end(JSON.stringify(translate(data)));
            }).catch((err) => {
                res.end(err);
            })
    };
}

/**
 * 分页查询构建器
 * @param {*} table 
 * @param {*} key 
 * @param {*} items 
 */
var pagedBuilder = (table, key, items,orderby="") => {
    return (req, res) => {
        var page = _.toInteger(_.get(req.query, 'page', 1));
        var pageSize = _.toInteger(_.get(req.query, 'pageSize', 10));
        _.unset(req.query, 'page');
        _.unset(req.query, 'pageSize');
        databaseHelper.pagedDbByJson(req.query, table, items, key, page, pageSize,orderby)
            .then((data) => {
                res.end(JSON.stringify(data));
            }).catch((err) => {
                res.end(JSON.stringify(err));
            })
    };
}

module.exports = {
    saveBuilder,
    listAllBuilder,
    pagedBuilder,
};